@@ -32,7 +32,7 @@ int exit_callback(int errcode) {
 int quit_callback(int errcode) {
 //	remove("/tmp/.battlegweled-save");
 #if HGW_FUNC
-	hgw_context_compat_destroy_quit(hgw_context);
+//	hgw_context_compat_destroy_quit(hgw_context);
 #endif
 
 	return 0;
